| Title: | Simple and Accessible Data from all Known Planets |
|---|---|
| Description: | The goal of 'planets' is to provide of very simple and accessible data containing basic information from all known planets. |
| Authors: | Alejandro Jiménez Rico [aut, cre] |
| Maintainer: | Alejandro Jiménez Rico <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-20 06:49:40 UTC |
| Source: | https://github.com/aljrico/planets |
A data set containing the most basic information available of all known planets.
This package contains basic information from all knwon Planets
planetsplanets
A data frame with 3915 observations of 12 variables
data(planets) plot( data = planets, `Mass (MJ)` ~ `Temperature (K)` )data(planets) plot( data = planets, `Mass (MJ)` ~ `Temperature (K)` )