Welcome to ClientVPS Mirrors

Help for package planets
Title: Simple and Accessible Data from all Known Planets
Version: 0.1.0
Description: The goal of 'planets' is to provide of very simple and accessible data containing basic information from all known planets.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
Depends: R (≥ 2.10)
NeedsCompilation: no
Packaged: 2019-08-06 11:29:40 UTC; alejandro
Author: Alejandro Jiménez Rico [aut, cre]
Maintainer: Alejandro Jiménez Rico <aljrico@gmail.com>
Repository: CRAN
Date/Publication: 2019-08-07 07:40:02 UTC

"Planets"

Description

A data set containing the most basic information available of all known planets.

This package contains basic information from all knwon Planets

Usage

planets

Format

A data frame with 3915 observations of 12 variables

Examples

data(planets)

plot(
data = planets,
`Mass (MJ)` ~ `Temperature (K)`
)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.